# PulpcoreClient::DistributionsApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](DistributionsApi.md#list) | **GET** /pulp/api/v3/distributions/ | List distributions



## list

> PaginatedDistributionResponseList list(opts)

List distributions

Provides base viewset for Distributions.

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::DistributionsApi.new
opts = {
  base_path: 'base_path_example', # String | Filter results where base_path matches value
  base_path__contains: 'base_path__contains_example', # String | Filter results where base_path contains value
  base_path__icontains: 'base_path__icontains_example', # String | Filter results where base_path contains value
  base_path__in: ['base_path__in_example'], # Array<String> | Filter results where base_path is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__iexact: 'name__iexact_example', # String | Filter results where name matches value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__iregex: 'name__iregex_example', # String | Filter results where name matches regex value
  name__istartswith: 'name__istartswith_example', # String | Filter results where name starts with value
  name__regex: 'name__regex_example', # String | Filter results where name matches regex value
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `name` - Name * `-name` - Name (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `base_path` - Base path * `-base_path` - Base path (descending) * `hidden` - Hidden * `-hidden` - Hidden (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_type: 'pulp_type_example', # String | Pulp type  * `core.artifact` - core.artifact * `file.file` - file.file
  pulp_type__in: ['pulp_type__in_example'], # Array<String> | Multiple values may be separated by commas.  * `core.artifact` - core.artifact * `file.file` - file.file
  q: 'q_example', # String | 
  repository: 'repository_example', # String | Filter results where repository matches value
  repository__in: ['repository__in_example'], # Array<String> | Filter results where repository is in a comma-separated list of values
  with_content: 'with_content_example', # String | Filter distributions based on the content served by them
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List distributions
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling DistributionsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**| Filter results where base_path matches value | [optional] 
 **base_path__contains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__icontains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__in** | [**Array&lt;String&gt;**](String.md)| Filter results where base_path is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__iexact** | **String**| Filter results where name matches value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__iregex** | **String**| Filter results where name matches regex value | [optional] 
 **name__istartswith** | **String**| Filter results where name starts with value | [optional] 
 **name__regex** | **String**| Filter results where name matches regex value | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;base_path&#x60; - Base path * &#x60;-base_path&#x60; - Base path (descending) * &#x60;hidden&#x60; - Hidden * &#x60;-hidden&#x60; - Hidden (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_type** | **String**| Pulp type  * &#x60;core.artifact&#x60; - core.artifact * &#x60;file.file&#x60; - file.file | [optional] 
 **pulp_type__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas.  * &#x60;core.artifact&#x60; - core.artifact * &#x60;file.file&#x60; - file.file | [optional] 
 **q** | **String**|  | [optional] 
 **repository** | [**String**](.md)| Filter results where repository matches value | [optional] 
 **repository__in** | [**Array&lt;String&gt;**](String.md)| Filter results where repository is in a comma-separated list of values | [optional] 
 **with_content** | **String**| Filter distributions based on the content served by them | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedDistributionResponseList**](PaginatedDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

